@@ -270,7 +270,7 @@ autoplot.calibration_spct <-
            geom = "line",
            time.format = "",
            tz = "UTC",
-           norm = NULL,
+           norm = NA,
            text.size = 2.5,
            idfactor = NULL,
            facets = FALSE,
@@ -279,19 +279,15 @@ autoplot.calibration_spct <-
            object.label = deparse(substitute(object)),
            na.rm = TRUE) {
 
-    if (is.null(idfactor)) {
-      idfactor <- getIdFactor(object)
-    }
-    if (is.na(idfactor) || !is.character(idfactor)) {
-      idfactor <- getMultipleWl(object) > 1L
-    }
+    force(object.label)
+    object <- apply_normalization(object, norm)
+    idfactor <- check_idfactor_arg(object, idfactor = idfactor)
 
     if (plot.data != "as.is") {
       return(
         autoplot(object = subset2mspct(object),
                  w.band = w.band,
                  range = range,
-                 norm = norm,
                  unit.out = unit.out,
                  pc.out = pc.out,
                  label.qty = label.qty,
@@ -312,8 +308,6 @@ autoplot.calibration_spct <-
       )
     }
 
-    force(object.label)
-
     annotations.default <-
       getOption("photobiology.plot.annotations",
                 default = c("boxes", "labels", "colour.guide", "peaks"))
@@ -338,7 +332,7 @@ autoplot.calibration_spct <-
              pc.out = pc.out,
              annotations = annotations,
              geom = geom,
-             norm = norm,
+             norm = FALSE, # cal_plot needs to be updated
              text.size = text.size,
              idfactor = idfactor,
              facets = facets,
@@ -361,8 +355,7 @@ autoplot.calibration_mspct <-
            ...,
            range = getOption("ggspectra.wlrange", default = NULL),
            unit.out = "ignored",
-           norm = getOption("ggspectra.normalize",
-                            default = "skip"),
+           norm = NA,
            pc.out = getOption("ggspectra.pc.out", default = FALSE),
            plot.data = "as.is",
            idfactor = TRUE,
@@ -371,8 +364,9 @@ autoplot.calibration_mspct <-
            na.rm = TRUE) {
 
     force(object.label)
+    object <- apply_normalization(object, norm)
+    idfactor <- check_idfactor_arg(object, idfactor = idfactor, default = TRUE)
 
-    idfactor <- validate_idfactor(idfactor = idfactor)
     # We trim the spectra to avoid unnecessary computations later
     if (!is.null(range)) {
       object <- trim_wl(object, range = range, use.hinges = TRUE, fill = NULL)
@@ -391,11 +385,10 @@ autoplot.calibration_mspct <-
     )
     if (is.calibration_spct(z) && "irrad.mult" %in% names(z)) {
       autoplot(object = z,
-               range = getOption("ggspectra.wlrange", default = NULL),
+               range = NULL, # trimmed above
                unit.out = unit.out,
-               norm = norm,
                pc.out = pc.out,
-               idfactor = idfactor,
+               idfactor = NULL, # use idfactor already set in z
                facets = facets,
                object.label = object.label,
                na.rm = na.rm,
@@ -404,11 +397,10 @@ autoplot.calibration_mspct <-
       z <- as.generic_spct(z)
       autoplot(object = z,
                y.name = paste("irrad.mult", plot.data, sep = "."),
-               range = getOption("ggspectra.wlrange", default = NULL),
+               range = NULL, # trimmed above
                unit.out = unit.out,
-               norm = norm,
                pc.out = pc.out,
-               idfactor = idfactor,
+               idfactor = NULL, # use idfactor already set in z
                facets = facets,
                object.label = object.label,
                na.rm = na.rm,
