@@ -2,6 +2,7 @@
 #'
 #' \code{stat_peaks} finds at which x positions local maxima are located. If
 #' you want find local minima, you can use \code{stat_valleys} instead.
+#' \strong{Axis flipping is currently not supported.}
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
 #'    \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs to be set
@@ -43,12 +44,12 @@
 #'   fitting. Currently only spline interpolation is implemented.
 #' @param chroma.type character one of "CMF" (color matching function) or "CC"
 #'   (color coordinates) or a \code{\link[photobiology]{chroma_spct}} object.
-#' @param label.fmt character  string giving a format definition for converting
-#'   values into character strings by means of function \code{\link{sprintf}}.
-#' @param x.label.fmt character  string giving a format definition for converting
-#'   $x$-values into character strings by means of function \code{\link{sprintf}}.
-#' @param y.label.fmt character  string giving a format definition for converting
-#'   $y$-values into character strings by means of function \code{\link{sprintf}}.
+#' @param label.fmt,x.label.fmt,y.label.fmt character  strings giving a format
+#'   definition for construction of character strings labels with function
+#'   \code{\link{sprintf}} from \code{x} and/or \code{y} values.
+#' @param x.label.transform,y.label.transform,x.colour.transform function Applied
+#'   to \code{x} or \code{y} values when constructing the character labels or
+#'   computing matching colours.
 #'
 #' @return A data frame with one row for each peak (or valley) found in the
 #'   data.
@@ -158,9 +159,18 @@ stat_peaks <- function(mapping = NULL,
                        label.fmt = "%.3g",
                        x.label.fmt = label.fmt,
                        y.label.fmt = label.fmt,
+                       x.label.transform = I,
+                       y.label.transform = I,
+                       x.colour.transform = x.label.transform,
                        na.rm = FALSE,
                        show.legend = FALSE,
                        inherit.aes = TRUE) {
+  if (!(is.function(x.label.transform) &&
+        is.function(y.label.transform) &&
+        is.function(x.colour.transform))) {
+    stop("'transform' arguments must be function defintions")
+  }
+
   ggplot2::layer(
     stat = StatPeaks, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -173,6 +183,9 @@ stat_peaks <- function(mapping = NULL,
                   label.fmt = label.fmt,
                   x.label.fmt = x.label.fmt,
                   y.label.fmt = y.label.fmt,
+                  x.label.transform = x.label.transform,
+                  y.label.transform = y.label.transform,
+                  x.colour.transform = x.colour.transform,
                   na.rm = na.rm,
                   ...)
   )
@@ -208,21 +221,29 @@ StatPeaks <-
                                             chroma.type,
                                             label.fmt,
                                             x.label.fmt,
-                                            y.label.fmt) {
-                     peaks.df <- photobiology::peaks(data,
-                                                     x.var.name = "x",
-                                                     y.var.name = "y",
-                                                     span = span,
-                                                     ignore_threshold = ignore_threshold,
-                                                     strict = strict,
-                                                     refine.wl = refine.wl,
-                                                     method = method,
-                                                     na.rm = FALSE)
-                     peaks.df[["x.label"]] <- sprintf(x.label.fmt, peaks.df[["x"]])
-                     peaks.df[["y.label"]] <- sprintf(y.label.fmt, peaks.df[["y"]])
+                                            y.label.fmt,
+                                            x.label.transform,
+                                            y.label.transform,
+                                            x.colour.transform) {
+                     peaks.df <-
+                       photobiology::peaks(data,
+                                           x.var.name = "x",
+                                           y.var.name = "y",
+                                           span = span,
+                                           ignore_threshold = ignore_threshold,
+                                           strict = strict,
+                                           refine.wl = refine.wl,
+                                           method = method,
+                                           na.rm = FALSE)
+                     peaks.df[["x.label"]] <-
+                       sprintf(x.label.fmt, x.label.transform(peaks.df[["x"]]))
+                     peaks.df[["y.label"]] <-
+                       sprintf(y.label.fmt, y.label.transform(peaks.df[["y"]]))
                      peaks.df[["wl.color"]] <-
-                       photobiology::fast_color_of_wl(peaks.df[["x"]], chroma.type = chroma.type)
-                     peaks.df[["BW.color"]] <-  black_or_white(peaks.df[["wl.color"]])
+                       photobiology::fast_color_of_wl(x.colour.transform(peaks.df[["x"]]),
+                                                      chroma.type = chroma.type)
+                     peaks.df[["BW.color"]] <-
+                       black_or_white(peaks.df[["wl.color"]])
                      peaks.df
                    },
                    default_aes = ggplot2::aes(label = after_stat(x.label),
@@ -250,9 +271,18 @@ stat_valleys <- function(mapping = NULL,
                          label.fmt = "%.3g",
                          x.label.fmt = label.fmt,
                          y.label.fmt = label.fmt,
+                         x.label.transform = I,
+                         y.label.transform = I,
+                         x.colour.transform = x.label.transform,
                          na.rm = FALSE,
                          show.legend = FALSE,
                          inherit.aes = TRUE) {
+  if (!(is.function(x.label.transform) &&
+        is.function(y.label.transform) &&
+        is.function(x.colour.transform))) {
+    stop("'transform' arguments must be function defintions")
+  }
+
   ggplot2::layer(
     stat = StatValleys, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -265,6 +295,9 @@ stat_valleys <- function(mapping = NULL,
                   label.fmt = label.fmt,
                   x.label.fmt = x.label.fmt,
                   y.label.fmt = y.label.fmt,
+                  x.label.transform = x.label.transform,
+                  y.label.transform = y.label.transform,
+                  x.colour.transform = x.colour.transform,
                   na.rm = na.rm,
                   ...)
   )
@@ -286,21 +319,29 @@ StatValleys <-
                                             chroma.type,
                                             label.fmt,
                                             x.label.fmt,
-                                            y.label.fmt) {
-                     valleys.df <- photobiology::valleys(data,
-                                                         x.var.name = "x",
-                                                         y.var.name = "y",
-                                                         span = span,
-                                                         ignore_threshold = ignore_threshold,
-                                                         strict = strict,
-                                                         refine.wl = refine.wl,
-                                                         method = method,
-                                                         na.rm = FALSE)
-                     valleys.df[["x.label"]] <- sprintf(x.label.fmt, valleys.df[["x"]])
-                     valleys.df[["y.label"]] <- sprintf(y.label.fmt, valleys.df[["y"]])
+                                            y.label.fmt,
+                                            x.label.transform,
+                                            y.label.transform,
+                                            x.colour.transform) {
+                     valleys.df <-
+                       photobiology::valleys(data,
+                                             x.var.name = "x",
+                                             y.var.name = "y",
+                                             span = span,
+                                             ignore_threshold = ignore_threshold,
+                                             strict = strict,
+                                             refine.wl = refine.wl,
+                                             method = method,
+                                             na.rm = FALSE)
+                     valleys.df[["x.label"]] <-
+                       sprintf(x.label.fmt, x.label.transform(valleys.df[["x"]]))
+                     valleys.df[["y.label"]] <-
+                       sprintf(y.label.fmt, y.label.transform(valleys.df[["y"]]))
                      valleys.df[["wl.color"]] <-
-                       photobiology::fast_color_of_wl(valleys.df[["x"]], chroma.type = chroma.type)
-                     valleys.df[["BW.color"]] <-  black_or_white(valleys.df[["wl.color"]])
+                       photobiology::fast_color_of_wl(x.colour.transform(valleys.df[["x"]]),
+                                                      chroma.type = chroma.type)
+                     valleys.df[["BW.color"]] <-
+                       black_or_white(valleys.df[["wl.color"]])
                      valleys.df
                    },
                    default_aes = ggplot2::aes(label = after_stat(x.label),
